summaryrefslogtreecommitdiffstats
path: root/lib/kopalette/kotabpalette.cc
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kopalette/kotabpalette.cc')
-rw-r--r--lib/kopalette/kotabpalette.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/kopalette/kotabpalette.cc b/lib/kopalette/kotabpalette.cc
index c1b7a8a2..0e798842 100644
--- a/lib/kopalette/kotabpalette.cc
+++ b/lib/kopalette/kotabpalette.cc
@@ -27,8 +27,8 @@
#include <kotabpalette.h>
#include "kopalettemanager.h"
-KoTabPalette::KoTabPalette(TQWidget * tqparent, const char * name)
- : KoPalette(tqparent, name)
+KoTabPalette::KoTabPalette(TQWidget * parent, const char * name)
+ : KoPalette(parent, name)
{
m_page = new KTabWidget(this);
m_page->setTabShape(TQTabWidget::Triangular);
@@ -48,7 +48,7 @@ void KoTabPalette::plug(TQWidget * w, const TQString & /*name*/, int position)
{
if (!w) return;
- w -> unsetFont(); // Use the tqparent font
+ w -> unsetFont(); // Use the parent font
m_page -> insertTab(w, w -> caption(), position);
show();